// java wrapper for vtkTransformFilter object
//

package vtk;
import vtk.*;

public class vtkTransformFilter extends vtkPointSetAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetMTime_2();
  public int GetMTime()
    { return GetMTime_2(); }

  private native void SetTransform_3(vtkAbstractTransform id0);
  public void SetTransform(vtkAbstractTransform id0)
    { SetTransform_3(id0); }

  private native long GetTransform_4();
  public vtkAbstractTransform GetTransform() {
    long temp = GetTransform_4();

    if (temp == 0) return null;
    return (vtkAbstractTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int FillInputPortInformation_5(int id0,vtkInformation id1);
  public int FillInputPortInformation(int id0,vtkInformation id1)
    { return FillInputPortInformation_5(id0,id1); }

  private native void SetOutputPointsPrecision_6(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_6(id0); }

  private native int GetOutputPointsPrecision_7();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_7(); }

  private native void SetTransformAllInputVectors_8(boolean id0);
  public void SetTransformAllInputVectors(boolean id0)
    { SetTransformAllInputVectors_8(id0); }

  private native boolean GetTransformAllInputVectors_9();
  public boolean GetTransformAllInputVectors()
    { return GetTransformAllInputVectors_9(); }

  private native void TransformAllInputVectorsOn_10();
  public void TransformAllInputVectorsOn()
    { TransformAllInputVectorsOn_10(); }

  private native void TransformAllInputVectorsOff_11();
  public void TransformAllInputVectorsOff()
    { TransformAllInputVectorsOff_11(); }

  public vtkTransformFilter() { super(); }

  public vtkTransformFilter(long id) { super(id); }
  public native long   VTKInit();

}
